@@ -33,7 +33,8 @@ def suggest_from_media(modeldata, reactions2run, media, verbose=False):
             rxns = set()
             for r in cpdnames[m.name].all_reactions():
                 if r not in modeldata.reactions:
-                    log_and_message(f"ERROR: {r} was not found in our reactions", stderr=verbose)
+                    if not modeldata.reactions[r].is_uptake_secretion:
+                        log_and_message(f"ERROR: {r} was not found in our reactions", stderr=verbose)
                     continue
                 for c in modeldata.reactions[r].all_compounds():
                     if c.name == m.name and c.location == 'e':
